==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/turtle/dialogs_cs.lua <==

dialogId("zel-v-zelva0", "font_big", "Can you see it? This must be that telepathic turtle.")
dialogStr("Ha, vidíš ji? To bude jistě ta telepatická želva.")


dialogId("zel-v-zelva1", "font_big", "Yes, this is it. The telepathic turtle.")
dialogStr("Ha, to je ona. Želva s telepatickými schopnostmi.")


dialogId("zel-m-fotky0", "font_small", "Well, I don’t know. Judging from those photos, it could be it.")
dialogStr("No, já nevím, podle těch fotek by to mohla být ona.")


dialogId("zel-m-fotky1", "font_small", "I am not sure... what about those telepathic powers?")
dialogStr("Nejsem si jistá... a co ty telepatické schopnosti?")


dialogId("zel-v-zmistnosti0", "font_big", "In any case we have to get it out of the room.")
dialogStr("V každém případě ji vystrkáme z místnosti.")


dialogId("zel-v-zmistnosti1", "font_big", "Let’s take out that turtle.")
dialogStr("Vyneseme ven z místnosti tu želvu.")


dialogId("zel-m-coto0", "font_small", "What are you doing?")
dialogStr("Co to děláš?")


dialogId("zel-m-coto1", "font_small", "What have you done?")
dialogStr("Proč jsi to udělal?")


dialogId("zel-m-coto2", "font_small", "What is it supposed to mean?")
dialogStr("Co to mělo znamenat?")


dialogId("zel-v-coto0", "font_big", "Where are you swimming?")
dialogStr("Kam plaveš?")


dialogId("zel-v-coto1", "font_big", "What should it mean?")
dialogStr("Co tě to napadlo?")


dialogId("zel-v-coto2", "font_big", "What happened to you?")
dialogStr("Co se to s tebou děje?")


dialogId("zel-m-nevim0", "font_small", "I don’t know...")
dialogStr("Já nevím...")


dialogId("zel-m-nevim1", "font_small", "I can’t realize...")
dialogStr("Já si nic neuvědomuju...")


dialogId("zel-v-nevim0", "font_big", "I don’t know what’s happening to me...")
dialogStr("Nevím, co se se mnou děje...")


dialogId("zel-v-nevim1", "font_big", "I didn’t want to...")
dialogStr("Já nevím, to samo...")


dialogId("zel-v-cosedeje", "font_big", "What’s happening to us?")
dialogStr("Co se to s námi jen děje?")


dialogId("zel-m-cimtoje", "font_small", "What can it mean?")
dialogStr("Čím to může být způsobeno?")


dialogId("zel-m-tazelva", "font_small", "This must be that turtle!")
dialogStr("To dělá ta želva!")


dialogId("zel-v-tazelva", "font_big", "This must be that turtle!")
dialogStr("To dělá ta želva!")


dialogId("zel-m-jasne", "font_small", "So there can be no doubts now - this is it. The one we are looking for!")
dialogStr("Tak teď už je to jasné - je to ona. Tu hledáme!")


dialogId("zel-v-pochyby", "font_big", "Doubtless, this is the turtle we are looking for!")
dialogStr("Teď už není pochyb, je to ta želva, kterou hledáme!")


dialogId("zel-m-potvora0", "font_small", "That beast!")
dialogStr("Ta potvora!")


dialogId("zel-m-potvora1", "font_small", "Stop it, you devil!")
dialogStr("Nech toho, ty mrcho!")


dialogId("zel-v-stacit0", "font_big", "Enough is enough!")
dialogStr("To už by tedy mohlo stačit!")


dialogId("zel-v-stacit1", "font_big", "Are you enjoying yourself?")
dialogStr("Bavíš se dobře?")


dialogId("zel-v-bizarni", "font_big", "So many bizarre shapes can only be found in a coral reef.")
dialogStr("Tolik bizarních tvarů se najde jen na korálovém útesu.")


dialogId("zel-m-priroda", "font_small", "These corals are Mother Nature’s wonders.")
dialogStr("Příroda se na těch korálech vyřádila.")


dialogId("zel-v-tvary", "font_big", "Where do so many bizarre shapes come from?")
dialogStr("Jak může vzniknout tolik bizarních tvarů?")


dialogId("zel-m-jednoduse", "font_small", "It’s easy - designers create tricky problems and leave the drawing to the graphic artists.")
dialogStr("Jednoduše - programátoři vytvoří zapeklitý problém a grafici to pak nakreslí.")


dialogId("zel-v-ukol", "font_big", "Our goal in this room is to get out that turtle.")
dialogStr("V této místnosti je naším úkolem dostat ven tu želvu.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/turtle/dialogs_cs.lua <==

dialogId("zel-v-zelva0", "font_big", "Can you see it? This must be that telepathic turtle.")
dialogStr("Ha, vidíš ji? To bude jistě ta telepatická želva.")


dialogId("zel-v-zelva1", "font_big", "Yes, this is it. The telepathic turtle.")
dialogStr("Ha, to je ona. Želva s telepatickými schopnostmi.")


dialogId("zel-m-fotky0", "font_small", "Well, I don’t know. Judging from those photos, it could be it.")
dialogStr("No, já nevím, podle těch fotek by to mohla být ona.")


dialogId("zel-m-fotky1", "font_small", "I am not sure... what about those telepathic powers?")
dialogStr("Nejsem si jistá... a co ty telepatické schopnosti?")


dialogId("zel-v-zmistnosti0", "font_big", "In any case we have to get it out of the room.")
dialogStr("V každém případě ji vystrkáme z místnosti.")


dialogId("zel-v-zmistnosti1", "font_big", "Let’s take out that turtle.")
dialogStr("Vyneseme ven z místnosti tu želvu.")


dialogId("zel-m-coto0", "font_small", "What are you doing?")
dialogStr("Co to děláš?")


dialogId("zel-m-coto1", "font_small", "What have you done?")
dialogStr("Proč jsi to udělal?")


dialogId("zel-m-coto2", "font_small", "What is it supposed to mean?")
dialogStr("Co to mělo znamenat?")


dialogId("zel-v-coto0", "font_big", "Where are you swimming?")
dialogStr("Kam plaveš?")


dialogId("zel-v-coto1", "font_big", "What should it mean?")
dialogStr("Co tě to napadlo?")


dialogId("zel-v-coto2", "font_big", "What happened to you?")
dialogStr("Co se to s tebou děje?")


dialogId("zel-m-nevim0", "font_small", "I don’t know...")
dialogStr("Já nevím...")


dialogId("zel-m-nevim1", "font_small", "I can’t realize...")
dialogStr("Já si nic neuvědomuju...")


dialogId("zel-v-nevim0", "font_big", "I don’t know what’s happening to me...")
dialogStr("Nevím, co se se mnou děje...")


dialogId("zel-v-nevim1", "font_big", "I didn’t want to...")
dialogStr("Já nevím, to samo...")


dialogId("zel-v-cosedeje", "font_big", "What’s happening to us?")
dialogStr("Co se to s námi jen děje?")


dialogId("zel-m-cimtoje", "font_small", "What can it mean?")
dialogStr("Čím to může být způsobeno?")


dialogId("zel-m-tazelva", "font_small", "This must be that turtle!")
dialogStr("To dělá ta želva!")


dialogId("zel-v-tazelva", "font_big", "This must be that turtle!")
dialogStr("To dělá ta želva!")


dialogId("zel-m-jasne", "font_small", "So there can be no doubts now - this is it. The one we are looking for!")
dialogStr("Tak teď už je to jasné - je to ona. Tu hledáme!")


dialogId("zel-v-pochyby", "font_big", "Doubtless, this is the turtle we are looking for!")
dialogStr("Teď už není pochyb, je to ta želva, kterou hledáme!")


dialogId("zel-m-potvora0", "font_small", "That beast!")
dialogStr("Ta potvora!")


dialogId("zel-m-potvora1", "font_small", "Stop it, you devil!")
dialogStr("Nech toho, ty mrcho!")


dialogId("zel-v-stacit0", "font_big", "Enough is enough!")
dialogStr("To už by tedy mohlo stačit!")


dialogId("zel-v-stacit1", "font_big", "Are you enjoying yourself?")
dialogStr("Bavíš se dobře?")


dialogId("zel-v-bizarni", "font_big", "So many bizarre shapes can only be found in a coral reef.")
dialogStr("Tolik bizarních tvarů se najde jen na korálovém útesu.")


dialogId("zel-m-priroda", "font_small", "These corals are Mother Nature’s wonders.")
dialogStr("Příroda se na těch korálech vyřádila.")


dialogId("zel-v-tvary", "font_big", "Where do so many bizarre shapes come from?")
dialogStr("Jak může vzniknout tolik bizarních tvarů?")


dialogId("zel-m-jednoduse", "font_small", "It’s easy - designers create tricky problems and leave the drawing to the graphic artists.")
dialogStr("Jednoduše - programátoři vytvoří zapeklitý problém a grafici to pak nakreslí.")


dialogId("zel-v-ukol", "font_big", "Our goal in this room is to get that turtle out.")
dialogStr("V této místnosti je naším úkolem dostat ven tu želvu.")
